Show fields
Show fields
return a new instance with token authentication
return a new instance of a builder for authentication
serialize authentication as JSON in base64
Formats the value using the given formatter. Read more
Serialize this value into the given Serde serializer. Read more
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
Instruments this type with the provided Span, returning an
Instrumented wrapper. Read more
Instruments this type with the current Span, returning an
Instrumented wrapper. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.